@@ -49,10 +49,7 @@ class Hanabira(Imageboard):
         if self.key:
             url = "%s/%s" % (url, self.key)
 
-        req = self.request(url)
-        if req.error or req.code != 200:
-            return self.error_http(req)
-        posts = simplejson.loads(req.data)
+        posts = self.assertJSON(req)
         return self.result(posts)
     
     def hide_post(self, post_id):
@@ -60,36 +57,32 @@ class Hanabira(Imageboard):
             return self.error(u"Admin key is needed for hide posts")
         url = '/api/admin/post/hide/%s/%s' % (post_id, self.key)
         req = self.request(url)
-        if req.error or req.code != 200:
-            return self.error_http(req)
-        return self.result(simplejson.loads(req.data))
+        doc = self.assertJSON(req)
+        return self.result(doc)
         
     def show_post(self, post_id):
         if not self.key:
             return self.error(u"Admin key is needed for show posts")
         url = '/api/admin/post/show/%s/%s' % (post_id, self.key)
         req = self.request(url)
-        if req.error or req.code != 200:
-            return self.error_http(req)
-        return self.result(simplejson.loads(req.data))
+        doc = self.assertJSON(req)
+        return self.result(doc)
     
     def ban_user(self, post_id):
         if not self.key:
             return self.error(u"Admin key is needed for ban user")
         url = '/api/admin/user/ban/%s/%s' % (post_id, self.key)
         req = self.request(url)
-        if req.error or req.code != 200:
-            return self.error_http(req)
-        return self.result(simplejson.loads(req.data))
+        doc = self.assertJSON(req)
+        return self.result(doc)
     
     def unban_user(self, post_id):
         if not self.key:
             return self.error(u"Admin key is needed for unban user")
         url = '/api/admin/user/unban/%s/%s' % (post_id, self.key)
         req = self.request(url)
-        if req.error or req.code != 200:
-            return self.error_http(req)
-        return self.result(simplejson.loads(req.data))
+        doc = self.assertJSON(req)
+        return self.result(doc)
 
     # Should be fixed later
     def parse_local_file(self, fp):
